@@ -31,6 +31,7 @@ from sun_sunos import SunSUNOS
 from freebsd import FreeBSD
 from iij_seil import IIJSeil
 from yamaha_rtx import YamahaRTX
+from fortinet_fortios import FortiOs
 from unknown import Unknown
 
 
@@ -215,6 +216,12 @@ def sysdescrparser(sysdescr):
     if obj.parse():
         return obj
     #
+    # fortigate
+    #
+    obj = FortiOs(sysdescr)
+    if obj.parse():
+        return obj
+    #
     # Unknown
     #
     obj = Unknown(sysdescr)
